@@ -25,7 +25,7 @@ class HierarchicalAdminForm(forms.ModelForm):
 
 class HierarchicalAdmin(admin.ModelAdmin):
 	list_display = (
-		'name',
+		'hierarchical_name',
 		'slug',
 		'parent'
 	)
@@ -37,6 +37,12 @@ class HierarchicalAdmin(admin.ModelAdmin):
 	}
 	
 	form = HierarchicalAdminForm
+	
+	def hierarchical_name(self, obj):
+		parents = '&nbsp;&nbsp;&nbsp;&nbsp;' * obj.slug_hierarchical.count('/')
+		return '%s%s' % (parents, obj.name)
+	hierarchical_name.allow_tags = True
+	hierarchical_name.short_description = 'Name'
 
 class SortableHierarchicalAdmin(HierarchicalAdmin):
 	list_display = HierarchicalAdmin.list_display + ('order',)
